﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Windows;
using System.Windows.Media.Imaging;
using Microsoft.Phone;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Tasks;

namespace PersistingAnImage
{
    public partial class MainPage : PhoneApplicationPage
    {
        private readonly CameraCaptureTask camera =
            new CameraCaptureTask();
        private readonly Dictionary<string, Person> people = new Dictionary<string, Person>();
        private byte[ ] thumbnail;

        public MainPage()
        {
            InitializeComponent();
            camera.Completed += Camera_Completed;
            PictureButton.Click += ( o, e ) => { camera.Show(); };
            NameTextBox.TextChanged += ( o, e ) =>
                {
                    FindButton.IsEnabled = SaveButton.IsEnabled = String.IsNullOrEmpty( NameTextBox.Text )
                        ? false : true;
                };
            SaveButton.Click += Save_Click;
            FindButton.Click += Find_Click;
        }

        private void Camera_Completed( object sender, PhotoResult e )
        {
            var imageBytes = new byte[e.ChosenPhoto.Length];
            e.ChosenPhoto.Read( imageBytes, 0, imageBytes.Length );
            e.ChosenPhoto.Seek( 0, SeekOrigin.Begin );
            Picture.Source = PictureDecoder.DecodeJpeg( e.ChosenPhoto );
            thumbnail = imageBytes;
        }

        private void Save_Click( object sender, RoutedEventArgs e )
        {
            Person p = new Person()
            {
                FullName = NameTextBox.Text,
                Thumbnail = thumbnail
            };
            Picture.Source = null;
            NameTextBox.Text = "";
            people.Add( p.FullName, p );
        }

        private void Find_Click( object sender, RoutedEventArgs e )
        {
            Picture.Source = null;

            if (!people.Keys.Contains( NameTextBox.Text ))
            {
                MessageBox.Show( NameTextBox.Text + " not found." );
                return;
            }

            var per = people[NameTextBox.Text];
            if (per.Thumbnail == null)
            {
                Picture.Source = null;
                return;
            }
            byte[ ] data = per.Thumbnail;

            using (Stream memStream = new MemoryStream( data ))
            {
                WriteableBitmap wbimg =
                    PictureDecoder.DecodeJpeg( memStream );
                Picture.Source = wbimg;
            }
        }
    }
}